import { LogoutOutlined } from '@ant-design/icons';
import { Avatar, Menu, Spin } from 'antd';
import { ClickParam } from 'antd/es/menu';
import React from 'react';
import { history, ConnectProps, connect } from 'umi';
import { ConnectState } from '@/models/connect';
import { CurrentUser } from '@/models/user';
import HeaderDropdown from '../HeaderDropdown';
import styles from './index.less';

export interface GlobalHeaderRightProps extends Partial<ConnectProps> {
  currentUser?: CurrentUser;
  menu?: boolean;
}

class AvatarDropdown extends React.Component<GlobalHeaderRightProps> {
  onMenuClick = (event: ClickParam) => {
    const { key } = event;

    if (key === 'logout') {
      const { dispatch } = this.props;

      if (dispatch) {
        // dispatch({
        //   type: 'user/deleteCurrent',
        // });

        // 清掉所有localStorage缓存
        // localStorage.clear();

        // 只用清掉当前账户的 localStorage
        localStorage.removeItem('userInfo');

        // 清掉本域名所有cookie
        let keys = document.cookie.match(/[^ =;]+(?==)/g);
        if (keys) {
          for (var i = keys.length; i--; ) {
            document.cookie = keys[i] + '=0;path=/;expires=' + new Date(0).toUTCString();
            document.cookie =
              keys[i] +
              '=0;path=/;domain=' +
              document.domain +
              ';expires=' +
              new Date(0).toUTCString();
            document.cookie =
              keys[i] + '=0;path=/;domain=ratingdog.cn;expires=' + new Date(0).toUTCString();
          }
        }

        // 在返回登录页
        // 刷新一下，避免 dva 的数据还存在
        window.location.pathname = '/';
        // dispatch({
        //   type: 'login/logout',
        // });
      }
      return;
    }

    history.push(`/account/${key}`);
  };

  render(): React.ReactNode {
    const {
      currentUser = {
        avatar: 'http://120.77.240.215:5205/file/ce90a1cd01cf4c2bb6ab12b295c25c16.png',
        name: 'Login Again Please',
      },
    } = this.props;

    const menuHeaderDropdown = (
      <Menu className={styles.menu} selectedKeys={[]} onClick={this.onMenuClick}>
        <Menu.Item key="logout">
          <LogoutOutlined />
          Sign Out
        </Menu.Item>
      </Menu>
    );

    return (
      <HeaderDropdown overlay={menuHeaderDropdown}>
        <span className={`${styles.action} ${styles.account}`}>
          <Avatar size="small" className={styles.avatar} src={currentUser.avatar} alt="avatar" />
          <span className={styles.name}>{currentUser.name}</span>
        </span>
      </HeaderDropdown>
    );
  }
}

export default connect(({ user }: ConnectState) => ({
  currentUser: user.currentUser,
}))(AvatarDropdown);
