import React, { useState, useEffect } from 'react';
import styles from './css/index.less';
import { Input, Menu, Table, Space, Upload, message, Pagination, Button } from 'antd';

import { Link, useIntl, connect, Dispatch, history } from 'umi';

import { timestampToTime3 } from '../../utils/time';

import TitleSearch from '../../components/TitleSearch/TitleSearch';
import { RA, urlEncode, filterObj, filterObjbyTg } from '@/utils/method';

const pathname = [
  'CommunityMaintenance', // 小区保养
  'ShelfLifeService', // 保质期服务
  'OwnerComplaints', // 业主投诉
  'ReportOnline', // 在线报事
  'ProblemFeedback', // 问题反馈
];

const handle_Status = [
  [0, 'Pending'],
  [1, 'Processed'],
]; //["未处理","处理","拒绝"] , [2,"Rejected"]
const goToName = ['Reply', 'Detail'];

const module = 'CommunityService';

interface DataType {
  handleStatus?: string | Array<string>;
  ownerName?: string;
  communityName?: string;
}

// 页码
let pageNum: any = 1;

let readyData: DataType = {
  handleStatus: '',
  ownerName: '',
  communityName: '',
};

const PropertyServices = (props: any) => {
  const permissionArr = JSON.parse(localStorage.getItem('permission') || '');
  const { dispatch, location, Data } = props;

  const [loading, setLoading] = useState(false);
  const [serviceTypeGobal, setServiceType] = useState('');
  // const [readyData, setReadyData] = useState(null);

  const columns = [
    { title: 'Community Name', dataIndex: 'community_name' },
    { title: 'Owner Name', dataIndex: 'owner_name' },

    {
      title: parseInt(serviceTypeGobal) - 1 === 0 ? 'Replier' : 'Content',
      dataIndex: parseInt(serviceTypeGobal) - 1 === 0 ? 'handle_name' : 'service_content',
      ellipsis: true,
      width: 400,
      render: (text: any) => <Space size="middle">{text != null ? text : '--'}</Space>,
    },

    {
      title: 'Create Time',
      dataIndex: 'create_time',
      render: (text: any, record: any) => (
        <Space size="middle">{timestampToTime3(text.time)}</Space>
      ),
    },
    {
      title: 'Status',
      dataIndex: 'id',
      render: (text: any, record: any) => (
        <Space size="middle">{handle_Status[record.handle_status][1]}</Space>
      ),
    },
    {
      title: 'Actions',
      dataIndex: 'handle_status',
      render: (text: any, record: any) => (
        <Space size="middle">
          <a onClick={goToDetail.bind(this, text, record)}>{goToName[text]}</a>
        </Space>
      ),
    },
  ];

  const goToDetail = (value: any, record: any, e: any) => {
    if (permissionArr.indexOf('12') < 0) {
      message.error('No Permissions!!!', 3);
      return;
    }
    //页面递进
    history.push(
      location.pathname +
        (value == 0 ? '/Edit' : '/Detail') +
        urlEncode({
          serviceType: serviceTypeGobal,
          id: record.id,
          user_id: record.user_id,
          community_id: record.community_id,
        }),
    );
  };

  useEffect(() => {
    if (Data != null) {
      setLoading(false);
    }
  }, [Data]);

  useEffect(() => {
    console.log(readyData);
    if (location != null) {
      //细分类：页面指令
      var serviceType = '';
      pathname.map((item, index) => {
        if (location.pathname.indexOf(item) > -1) {
          serviceType = '' + (index + 1);
          setServiceType(serviceType);
        }
      });
      //分页设置
      if (location.query.pageNum != null) {
        pageNum = parseInt(location.query.pageNum);
      } else {
        pageNum = 1;
      }

      //前置数据
      var tmp: DataType = filterObjbyTg(location.query, [
        'handleStatus',
        'ownerName',
        'communityName',
      ]);
      console.log(tmp);
      tmp.ownerName = tmp.ownerName || '';
      tmp.communityName = tmp.communityName || '';
      tmp.handleStatus = handle_Status[parseInt(tmp.handleStatus as string)] as Array<string>; //特殊处理
      console.log(tmp);
      // setReadyData(tmp);
      readyData = {
        ...tmp,
      };
      //获取数据
      setLoading(true);
      RA(
        40,
        {
          serviceType: serviceType,
          ...tmp,
          handleStatus:
            location.query.handleStatus != undefined ? parseInt(location.query.handleStatus) : null,
          pageNum,
        },
        module,
        dispatch,
      );
    }

    return () => {
      readyData = {
        ...readyData,
        handleStatus: '',
        ownerName: '',
        communityName: '',
      };
    };
  }, [location]);

  const PageChange = (values: any) => {
    //页面跳转参数
    var tmp = filterObjbyTg(location.query, ['handleStatus', 'ownerName', 'communityName']);
    tmp['pageNum'] = values.current;
    history.push(location.pathname + urlEncode(tmp));
  };

  const ClickTitleSearch = (comment: any) => {
    //页面搜索
    // comment.serviceType = serviceTypeGobal;
    comment.pageNum = 1;
    history.push(location.pathname + urlEncode(filterObj(comment)));
  };

  return (
    <div className={styles.base}>
      <TitleSearch
        communitySelect={true}
        listkey={['ownerName']}
        list={['Owner Name']}
        status={[{ name: ['handleStatus', 'Status'], data: handle_Status }]}
        defaultValue={readyData}
        onSubmit={ClickTitleSearch}
      />
      <Table
        rowKey={'id'}
        style={{ marginTop: 16 }}
        loading={loading}
        columns={columns}
        dataSource={Data != null ? Data.data.rows : []}
        pagination={{
          pageSize: Data != null ? Data.data.page.curPageSize : 0,
          current: parseInt(pageNum),
          total: Data != null ? Data.data.page.totalRow : 0,
          showSizeChanger: false,
        }}
        onChange={PageChange}
      />
    </div>
  );
};

function mapStateToProps(state: any) {
  const { Data } = state.CommunityService;
  return {
    Data,
  };
}
export default connect(mapStateToProps)(PropertyServices);
